package com.ruoyi.app.service;

import java.util.List;
import com.ruoyi.app.model.Hook;

/**
 * 吊钩Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IHookService 
{
    /**
     * 查询吊钩
     * 
     * @param id 吊钩主键
     * @return 吊钩
     */
    public Hook selectHookById(Long id);

    /**
     * 查询吊钩列表
     * 
     * @param hook 吊钩
     * @return 吊钩集合
     */
    public List<Hook> selectHookList(Hook hook);

    /**
     * 校验吊钩名称是否唯一
     *
     * @param  hook 吊钩名称
     * @return 结果
     */
    public boolean checkHookNameUnique(Hook hook);

    /**
     * 新增吊钩
     * 
     * @param hook 吊钩
     * @return 结果
     */
    public int insertHook(Hook hook);

    /**
     * 修改吊钩
     * 
     * @param hook 吊钩
     * @return 结果
     */
    public int updateHook(Hook hook);

    /**
     * 批量删除吊钩
     * 
     * @param ids 需要删除的吊钩主键集合
     * @return 结果
     */
    public int deleteHookByIds(Long[] ids);

    /**
     * 删除吊钩信息
     * 
     * @param id 吊钩主键
     * @return 结果
     */
    public int deleteHookById(Long id);
}
